# Seatools Python集成式工具包 (Python >= 3.9)


## 仓库地址:
1. https://github.com/seatools-py/seatools
2. https://gitee.com/seatools-py/seatools

## Cookiecutter-seatools-python 模板项目地址
1. https://github.com/seatools-py/cookiecutter-seatools-python
2. https://gitee.com/seatools-py/cookiecutter-seatools-python


## 该仓库设立初衷旨在针对各业务场景提供更编辑的操作方式, 并且任意工具均可按需安装依赖, 使得程序更轻量

## 联系方式, qq: 521274311 邮箱: 521274311@qq.com

## 安装
```shell
pip install seatools --upgrade
```


## APIs
### [一. `seatools.logger` 日志工具包(通过setup方法设置日志文件+loguru框架记录日志)](./docs/日志工具包.md)
### [二. `seatools.builders` 特定格式内容建造器, 例如: html标签, markdown语法等](./docs/Html、Markdown建造器.md)
### [三. `seatools.files` 文件/文件类型数据处理工具, 例如: json, csv, yaml, ini等](./docs/文件或文件类型数据处理工具.md)
### [四. `seatools.models` pydantic Model 封装等, 墙裂推荐, 业务上均应该使用pydantic](./docs/pydantic封装.md)
### [五. `seatools.notices` 通知工具, 例如: 飞书通知、邮箱通知等](./docs/通知工具.md)
### [六. `seatools.cryptography` 常用加密解密包, 例如: md5, base64, hmac等](./docs/常用加密解密工具.md)
### [七、`seatools.env` 多环境管理工具包, 例如: 开发环境、测试环境、正式环境等](./docs/多环境工具包.md)
### [八、`seatools.sqlalchemy` sqlalchemy ORM工具包](./docs/sqlalchemy工具包.md)
### [九、`seatools.retry` 重试工具](./docs/重试工具.md)
### [十、`seatools.task` 任务工具](./docs/任务工具.md)
### [十一、`seatools.cache` 缓存工具](./docs/缓存工具.md)
### [十二、`seatools.ioc` 轻量级ioc工具](./docs/ioc工具.md), [ioc详解](./docs/ioc详解.md)
### [十三、`seatools.redis_om` redis-om拓展](./docs/redis-om拓展.md)
### [十四、`seatools.uc` undetected-chromedriver拓展工具](./docs/undetected-chromedriver拓展工具.md)
